Package: combinat
Version: 0.0-8
Title: combinatorics utilities
Author: Scott Chasalow
Maintainer: Vince Carey <stvjc@channing.harvard.edu>
Description: routines for combinatorics
License: GPL-2
Repository: CRAN
Date/Publication: 2012-10-29 08:58:26
Packaged: 2012-10-29 08:58:26 UTC; ripley
Built: R 4.3.3; ; 2025-01-24 03:19:50 UTC; unix
