Package: combinat
Version: 0.0-8
Title: combinatorics utilities
Author: Scott Chasalow
Maintainer: Vince Carey <stvjc@channing.harvard.edu>
Description: routines for combinatorics
License: GPL-2
Repository: CRAN
Date/Publication: 2012-10-29 08:58:26
Packaged: 2012-10-29 08:58:26 UTC; ripley
Built: R 4.6.0; ; 2026-04-26 09:47:26 UTC; unix
